@@ -1,5 +1,5 @@
 /*
- * $Id: radexample.c,v 1.3 1996/03/18 23:20:26 lf Exp $
+ * $Id: radexample.c,v 1.4 1996/05/05 00:13:36 lf Exp $
  *
  * Copyright (C) 1995,1996 Lars Fenneberg
  *
@@ -11,18 +11,18 @@
 
 
 static char	rcsid[] =
-		"$Id: radexample.c,v 1.3 1996/03/18 23:20:26 lf Exp $";
-
-static char	copyright_1[] =
-		"$Copyright: (C) 1995,1996 Lars Fenneberg $";
+		"$Id: radexample.c,v 1.4 1996/05/05 00:13:36 lf Exp $";
 
 #include	<sys/types.h>
 
 #include	<syslog.h>
 #include	<string.h>
 
-#include	"../src/radius.h"
-#include	"../src/pathnames.h"
+#include	"config.h"
+#include	"radius.h"
+#include	"pathnames.h"
+
+static char *pname = NULL;
 
 int
 main (int argc, char **argv)
@@ -33,12 +33,17 @@ main (int argc, char **argv)
 	VALUE_PAIR 	*send, *received;
 	UINT4		service;
 	char 		msg[4096], username_realm[256];
+	char		*default_realm = rc_conf_str("default_realm");
 
-	if (rc_read_config(_PATH_ETC_RADIUSCLIENT_CONF) != 0)
-		exit(ERROR_RC);
+	pname = (pname = strrchr(argv[0],'/'))?pname+1:argv[0];
+
+	rc_openlog(pname);
+
+	if (rc_read_config(_PATH_RADIUSCLIENT_CONF) != 0)
+		return(ERROR_RC);
 	
-	if (rc_read_dictionary(conf_dictionary) != 0)
-		exit (ERROR_RC);
+	if (rc_read_dictionary(rc_conf_str("dictionary")) != 0)
+		return(ERROR_RC);
 
 	strncpy(username, rc_getstr ("login: ",1), sizeof(username));
 	strncpy (passwd, rc_getstr("Password: ",0), sizeof (passwd));		
@@ -52,37 +57,40 @@ main (int argc, char **argv)
 	strncpy(username_realm, username, sizeof(username_realm));
 
 	/* Append default realm */
-	if ((strchr(username_realm, '@') == NULL) && conf_default_realm &&
-	    (*conf_default_realm != '\0'))
+	if ((strchr(username_realm, '@') == NULL) && default_realm &&
+	    (*default_realm != '\0'))
 	{
 		strncat(username_realm, "@", sizeof(username_realm));
-		strncat(username_realm, conf_default_realm, sizeof(username_realm));
+		strncat(username_realm, default_realm, sizeof(username_realm));
 	} 
 
-	rc_avpair_add(&send, PW_USER_NAME, username_realm);
+	if (rc_avpair_add(&send, PW_USER_NAME, username_realm) == NULL)
+		return(ERROR_RC);
 	
 	/*
 	 * Fill in User-Password
 	 */
 	 
-	rc_avpair_add(&send, PW_USER_PASSWORD, passwd); 	  
+	if (rc_avpair_add(&send, PW_USER_PASSWORD, passwd) == NULL)
+		return (ERROR_RC);
 
 	/*
 	 * Fill in Service-Type
 	 */
 	
 	service = PW_AUTHENTICATE_ONLY;
-	rc_avpair_add(&send, PW_SERVICE_TYPE, &service);
+	if (rc_avpair_add(&send, PW_SERVICE_TYPE, &service) == NULL)
+		return (ERROR_RC);	
 	
 	result = rc_auth(0, send, &received, msg);
 	
 	if (result == OK_RC)
 	{
-		rc_log(LOG_NOTICE, "\"%s\" RADIUS authentication OK", username);
+		fprintf(stderr, "\"%s\" RADIUS Authentication OK\n", username);
 	}
 	else
 	{
-		rc_log(LOG_NOTICE, "\"%s\" RADIUS authentication failed (RC=%i)", username, result);
+		fprintf(stderr, "\"%s\" RADIUS Authentication failure (RC=%i)\n", username, result);
 	}
 	
 	return result;
