@@ -1,5 +1,5 @@
 /*
- * $Id: getifname.c,v 1.3 1996/01/06 01:58:18 lf Exp $
+ * $Id: getifname.c,v 1.4 1996/05/05 00:13:21 lf Exp $
  *
  * Copyright (C) 1995 Lars Fenneberg
  *
@@ -12,18 +12,25 @@
 #include <stdio.h>
 #include <syslog.h>
 #include <unistd.h>
+#include <string.h>
 
+#include "config.h"
 #include "radius.h"
 
-static char rcsid[] = "$Id: getifname.c,v 1.3 1996/01/06 01:58:18 lf Exp $";
+static char rcsid[] = "$Id: getifname.c,v 1.4 1996/05/05 00:13:21 lf Exp $";
 
-void main(int argc, char **argv)
+int main(int argc, char **argv)
 {
 	char *p;
+	char *pname;
+	
+	pname = (pname = strrchr(argv[0],'/'))?pname+1:argv[0];
+
+	rc_openlog(pname);
 
 	if (argc > 2) {
-		rc_log(LOG_ERR,"usage: %s [filename]", argv[0]);
-		exit(1);
+		fprintf(stderr, "usage: %s [filename]", pname);
+		return(ERROR_RC);
 	} else if (argc == 2) {
 	 	p = rc_getifname(argv[1]);
 		if (p) fputs(p, stdout);
@@ -31,4 +38,6 @@ void main(int argc, char **argv)
 		p = rc_getifname(ttyname(1));
 		if (p) fputs(p, stdout);
 	}	
+
+	return 0;
 }
